@@ -149,11 +149,11 @@ test_that("map.feature colors", {
   expect_equal(map_colors$x$calls[[4]]$args[6][[1]]$color, c("#000080", "#9ACD32"))
   expect_equal(map_colors2$x$calls[[4]]$args[6][[1]]$color, c("#000080", "#9ACD32"))
   expect_equal(map_colorless$x$calls[[4]]$args[6][[1]]$color,
-               c("#1F77B4", "#1F77B4"))
+               c("#1f77b4", "#1f77b4"))
   expect_equal(map_colorless2$x$calls[[4]]$args[6][[1]]$color,
                c("#F7FCFD", "#4D004B"))
   expect_equal(map_lang_colors$x$calls[[4]]$args[6][[1]]$color,
-               c("#000080", "#000080"))
+               c("navy", "navy"))
   expect_equal(
     map_stroke$x$calls[[4]]$args[6][[1]]$color,
     c("#FFFFFF", "#FFFFFF", "#000000", "#000000", "#000000")
